@@ -106,7 +106,7 @@ class mysql:
               if isinstance(df, pd.DataFrame):
                   valid=True
                   break
-          except Exception as e
+          except Exception as e:
               falla='Err mysql;'+str(e)
               out().print(falla)
               nada=0
